Learn R Programming

aphylo (version 0.2-1)

aphylo-index: Indexing aphylo objects

Description

Indexing aphylo objects

Usage

# S3 method for aphylo
[(x, i, j, drop = FALSE)

# S3 method for aphylo [(x, i, j) <- value

Arguments

x

An object of class aphylo.

i, j

Integer vector. Indices of genes or functions.

drop

Logical scalar. When TRUE, the function returns a matrix of annotations. Otherwise an object of class aphylo.

value

Integer vector. Replacing values, can be either c(0, 1, 9, NA).

Value

  • When indexing with i: A data frame with the annotations of the selected genes.

  • When only indexing with j (drop = FALSE): An aphylo object with the selected sets of annotations.

  • When only indexing with j (drop = TRUE): A data.frame with the selected annotations.

  • When indexing on both i and j: A data.frame with the selected genes and annotations.

Details

The subsetting method allows selecting one or more annotations from the aphylo object. Whenever i is specified, then aphylo returns the corresponding annotations.

Examples

Run this code
# NOT RUN {
set.seed(12312)
atree <- raphylo(50, P = 4)
atree[1:10,]
atree[,2:3]
atree[, 2:3, drop = TRUE]
atree[1:10, 2:3]


# }

Run the code above in your browser using DataLab