Logical scalar. When TRUE, the function returns a matrix of
annotations. Otherwise an object of class aphylo.
value
Integer vector. Replacing values, can be either c(0, 1, 9, NA).
Value
When indexing with i: A data frame with the annotations of the
selected genes.
When only indexing with j (drop = FALSE): An aphylo object with the selected sets of
annotations.
When only indexing with j (drop = TRUE): A data.frame with the selected
annotations.
When indexing on both i and j: A data.frame with the selected genes and annotations.
Details
The subsetting method allows selecting one or more annotations from
the aphylo object. Whenever i is specified, then aphylo returns the corresponding
annotations.